<TeXmacs|1.99.1>

<style|<tuple|letter|maple>>

<\body>
  <em|<strong|AppSing is a Maple Package for removing apparent singularities
  of systems of linear differential equations with rational function
  coefficien<em|>ts.<\footnote>
    M.A. Barkatou, S.S. Maddah (2015). Removing Apparent Singularities of
    Systems of Linear Differential Equations with<nbsp> Rational Function
    Coefficients. To appear in Proceedings of the 40th International
    Symposium on Symbolic and Algebraic Computation<hlink||http://www.issac-symposium.org/2015/>,
    ACM Press.
  </footnote> In what follows, we describe its two main procedures: Desing
  and Desingp. >>

  \;

  <section|Desingularization at p>

  \;

  <strong|Desingp> <emdash> \ constructs an equivalent system with rational
  function coefficients, which is a desingularization of the input system at
  p.

  \;

  <strong|Calling sequence>

  Desingp(A, z, p)

  \;

  <strong|Parameters>

  <\itemize-arrow>
    <item>A \ \ \ \ - the matrix of the system <math|<tfrac|d|dz> X=
    A<around*|(|z|)> X>

    <item>z \ \ \ \ \ - the independet variable\ 

    <item>p \ \ \ \ \ - a polynomial in z\ 

    \;
  </itemize-arrow>

  <strong|Returned Values>

  T, invT, B, t := Desingp(A, z, p);

  <\itemize-arrow>
    <item>B \ \ \ \ \ - the matrix of the resulting equivalent system
    \ <math|<tfrac|d|dz> Y= B<around*|(|z|)> Y>\ 

    <item>T \ \ \ \ \ - the transformation matrix (gauge transformation)
    corresponding to \ \ \ \ \ \ \ \ \ \ \ this desingularization (Y = T X)

    <item>invT \ - the inverse of the transformation matrix T

    <item>t \ \ \ \ \ \ - the execution time
  </itemize-arrow>

  <\strong>
    \;

    Examples
  </strong>

  <\session|maple|default>
    \;

    <\input>
      <with|color|brown|Maple 1] >
    <|input>
      with(LinearAlgebra): with(DETools):
    </input>

    <\folded-io>
      <with|color|brown|Maple 2] >
    <|folded-io>
      libname := "/Users/maddah/Documents/Implementations/AppSing/AppSing.lib",
      "/Library/Frameworks/Maple.framework/Versions/17/lib";
    <|folded-io>
      <math|`*`/U*s*e*r*s/m*a*d*d*a*h/D*o*c*u*m*e*n*t*s/I*m*p*l*e*m*e*n*t*a*t*i*o*n*s/A*p*p*S*i*n*g/A*p*p*S*i*n*g.*l*i*b<rprime|''>,`*`/L*i*b*r*a*r*y/F*r*a*m*e*w*o*r*k*s/M*a*p*l*e.*f*r*a*m*e*w*o*r*k/V*e*r*s*i*o*n*s/17/l*i*b<rprime|''>>
    </folded-io>

    <\folded-io>
      <with|color|brown|Maple 21] >
    <|folded-io>
      march('list', "/Users/maddah/Documents/Implementations/AppSing/AppSing.lib");
    <|folded-io>
      <math|<around|[|<around|[|`*`*R*e*s*i*d*T.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,1024,191|]>,<around|[|`*`*R*e*s*i*d.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,1215,329|]>,<around|[|`*`*D*e*s*i*n*g.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,1544,817|]>,<around|[|`*`*s*q*r*d*e*n*o*m.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,13205,367|]>,<around|[|`*`*g*c*d*p*o*l.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,13572,243|]>,<around|[|`*`*D*e*s*i*n*g*P*t*S*t*e*p*s.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,14694,1405|]>,<around|[|`*`*D*e*s*i*n*g*S*t*e*p*s.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,18093,959|]>,<around|[|`*`*S*h*e*a*r*i*n*g*T*r*a*n*s*p.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,5335,494|]>,<around|[|`*`*D*e*s*i*n*g*P*t.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,5829,1042|]>,<around|[|`*`*E*x*t.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,6871,135|]>,<around|[|`*`*G*a*u*s*s*A*l*p*h*a.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,7006,491|]>,<around|[|`*`*f<rsub|v>*a*l*p*o*l*y.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,14390,155|]>,<around|[|`*`*f<rsub|v>*a*l*u*a*t*i*o*n.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,14545,149|]>,<around|[|`*`*D*e*s*i*n*g*p.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,7801,1763|]>,<around|[|`*`*C*h*e*c*k*R*a*t.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,9564,362|]>,<around|[|`*`*G*a*u*s*s*C*o*m*p*l*e*t*e*B*a*s*i*s.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,12850,355|]>,<around|[|`*`*N*o*n*N*e*g*a*t*i*v*e*I*n*t*e*g*e*r*R*o*o*t*s.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,13815,575|]>,<around|[|`*`*D*e*s*i*n*g*p*S*t*e*p*s.*m<rprime|''>,<around|[|2015,4,14,23,35,2|]>,16099,1994|]>|]>>
    </folded-io>

    \;

    \;

    \;

    \;

    \;

    <with|color|pastel orange|<strong|<with|color|red|Example 1>>:>

    \;

    <\unfolded-io>
      <with|color|brown|Maple 18] >
    <|unfolded-io>
      A := Matrix(2, 2, [0, 1, (4*z^2-2)/(z^2+2), -(3*z^2-4)/(z*(z^2+2))]);
    <|unfolded-io>
      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|<frac|4
      z<rsup|2>-2|z<rsup|2>+2>>|<cell|-<frac|3*<space|0.17em>z<rsup|2>-4|z*<around*|(|z<rsup|2>+2|)>>>>>>>|]>><text|>
    </unfolded-io>

    \;

    \;

    The roots of <math|z<rsup|2>+2> are not apparent singularities. In fact,
    the eigenvalues of the corresponding residue matrix don't fulfill the
    requirements.

    \;

    <\unfolded-io>
      <with|color|brown|Maple 19] >
    <|unfolded-io>
      T, invT, B, t := Desingp(A, z, z^2+2);
    <|unfolded-io>
      <math|>

      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|1>|<cell|0>>|<row|<cell|0>|<cell|1>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|1>|<cell|0>>|<row|<cell|0>|<cell|1>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|2*<space|0.17em><frac|2*<space|0.17em>z<rsup|2>-1|z<rsup|2>+2>>|<cell|-<frac|3*<space|0.17em>z<rsup|2>-4|z*<around*|(|z<rsup|2>+2|)>>>>>>>|]>,0.064><text|>
    </unfolded-io>

    \;

    \;

    <math|z = 0> is an apparent singularity: It is removed in the equivalent
    system.

    \;

    \;

    \;

    <\unfolded-io>
      <with|color|brown|Maple 20] >
    <|unfolded-io>
      T, invT, B, t := Desingp(A, z, z);
    <|unfolded-io>
      \;

      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|z<rsup|2>>|<cell|z>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|-z<rsup|-1>>|<cell|z<rsup|-2>>>|<row|<cell|1>|<cell|0>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|-<frac|z*<around*|(|z<rsup|2>+7|)>|z<rsup|2>+2>>|<cell|-1>>|<row|<cell|z<rsup|2>>|<cell|z>>>>>|]>,0.230>

      \;

      \;
    </unfolded-io>

    \;

    \;

    \;

    \;

    \;

    <with|color|pastel orange|<strong|<with|color|red|Example 2>>><\footnote>
      Shaoshi Chen, M. Jaroschek, M. Kauers, M. F. Singer (2013).
      Desingularization Explains Order-Degree

      Curves for Ore Operators, Proceedings of the 38th International
      Symposium on Symbolic and Algebraic

      Computation, pp 157-164, ACM, U.S.A.\ 
    </footnote>

    \;

    <\unfolded-io>
      <with|color|brown|Maple 7] >
    <|unfolded-io>
      A := Matrix(2, 2, [0, 1, (2*x^4-x^3-35*x^2+25*x+45)/((x+1)*(2*x^3-x^2-20*x+23)),
      -(2*(-x^3-3*x^2-9*x+33))/((x+1)*(2*x^3-x^2-20*x+23))]);<text|>
    <|unfolded-io>
      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|<frac|2*<space|0.17em>x<rsup|4>-x<rsup|3>-35*<space|0.17em>x<rsup|2>+25*<space|0.17em>x+45|<around*|(|x+1|)>*<around*|(|2*<space|0.17em>x<rsup|3>-x<rsup|2>-20*<space|0.17em>x+23|)>>>|<cell|-2*<space|0.17em><frac|-x<rsup|3>-3*<space|0.17em>x<rsup|2>-9*<space|0.17em>x+33|<around*|(|x+1|)>*<around*|(|2*<space|0.17em>x<rsup|3>-x<rsup|2>-20*<space|0.17em>x+23|)>>>>>>>|]>>
    </unfolded-io>

    \;

    \;

    The roots of <math|2*<space|0.17em>x<rsup|3>-x<rsup|2>-20*<space|0.17em>x+23>
    are apparent singularities. They are removed in the equivalent system.

    \;

    \;

    <\unfolded-io>
      <with|color|brown|Maple 8] >
    <|unfolded-io>
      T, invT, B, t := Desingp(A, x, 2*x^3-x^2-20*x+23);
    <|unfolded-io>
      \;

      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|2*<space|0.17em>x<rsup|3>-x<rsup|2>-20*<space|0.17em>x+23>|<cell|-<frac|14|143>*<space|0.17em>x<rsup|2>+3/11*<space|0.17em>x+<frac|153|143>>>|<row|<cell|0>|<cell|1>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|<around*|(|2*<space|0.17em>x<rsup|3>-x<rsup|2>-20*<space|0.17em>x+23|)><rsup|-1>>|<cell|<frac|1|143>*<space|0.17em><frac|14*<space|0.17em>x<rsup|2>-39*<space|0.17em>x-153|2*<space|0.17em>x<rsup|3>-x<rsup|2>-20*<space|0.17em>x+23>>>|<row|<cell|0>|<cell|1>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|<frac|1|143>*<space|0.17em><frac|14*<space|0.17em>x<rsup|3>-39*<space|0.17em>x<rsup|2>-258*<space|0.17em>x-175|x+1>>|<cell|-<frac|1|20449>*<space|0.17em><frac|98*<space|0.17em>x<rsup|2>-497*<space|0.17em>x-1385|x+1>>>|<row|<cell|<frac|2*<space|0.17em>x<rsup|4>-x<rsup|3>-35*<space|0.17em>x<rsup|2>+25*<space|0.17em>x+45|x+1>>|<cell|-<frac|1|143>*<space|0.17em><frac|14*<space|0.17em>x<rsup|3>-39*<space|0.17em>x<rsup|2>-258*<space|0.17em>x+111|x+1>>>>>>|]>,0.303>
    </unfolded-io>

    <\input>
      <with|color|brown| >
    <|input>
      \;
    </input>
  </session>

  <section|Full desingularization>

  <strong|Desing> <emdash> \ constructs an equivalent system with rational
  function coefficients, whose finite singularities are exactly the
  non-apparent singularities of the input system.

  \;

  <strong|Calling sequence>

  Desing(A, z)

  \;

  <strong|Parameters>

  <\itemize-arrow>
    <item>A \ \ \ \ - the matrix of the system <math|<tfrac|d|dz> X=
    A<around*|(|z|)> X>

    <item>z \ \ \ \ \ - the independet variable
  </itemize-arrow>

  <\strong>
    \;

    Returned Values
  </strong>

  T, invT, B, t := Desing(A, z);

  <\itemize-arrow>
    <item>B \ \ \ \ \ - the matrix of the resulting equivalent system
    \ <math|<tfrac|d|dz> Y= B<around*|(|z|)> Y>\ 

    <item>T \ \ \ \ \ - the transformation matrix (gauge transformation)
    corresponding to \ \ \ \ \ \ \ \ \ \ \ this desingularization (Y = T X)

    <item>invT \ - the inverse of the transformation matrix T

    <item>t \ \ \ \ \ \ - the execution time
  </itemize-arrow>

  <\strong>
    \;

    Examples
  </strong>

  \;

  <strong|<with|color|red|<strong|Example> 3<strong|>>>

  <\session|maple|default>
    <\unfolded-io>
      <with|color|brown|Maple 9] >
    <|unfolded-io>
      A := Matrix(2, 2, [0, 1, (4*z^2-2)/(z^2+2), -(3*z^2-4)/(z*(z^2+2))]);
    <|unfolded-io>
      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|<frac|4*<space|0.17em>z<rsup|2>-2|z<rsup|2>+2>>|<cell|-<frac|3*<space|0.17em>z<rsup|2>-4|z*<around*|(|z<rsup|2>+2|)>>>>>>>|]>>
    </unfolded-io>

    <\unfolded-io>
      <with|color|brown|Maple 10] >
    <|unfolded-io>
      T, invT, B, t := Desing(A, z);
    <|unfolded-io>
      \;

      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|z<rsup|2>>|<cell|z>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|-z<rsup|-1>>|<cell|z<rsup|-2>>>|<row|<cell|1>|<cell|0>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|-<frac|z*<around*|(|z<rsup|2>+7|)>|z<rsup|2>+2>>|<cell|-1>>|<row|<cell|z<rsup|2>>|<cell|z>>>>>|]>,0.307>
    </unfolded-io>

    \;

    \;

    <strong|<with|color|red|<strong|Example> 4<\footnote>
      <\with|color|black>
        Shaoshi Chen, M. Kauers, M. F. Singer (2014). Desingularization of
        Ore Operators, Available at: arXiv:1408.5512v1, (2014)<strong|>
      </with>
    </footnote><strong|>>>

    \;

    <\unfolded-io>
      <with|color|brown|Maple 11] >
    <|unfolded-io>
      A := Matrix(2, 2, [0, 1, -(x-2)*(2*x^2-3*x+3)/((x-1)*(x^2-3*x+3)*x),
      (x^2-3)*(x^2-2*x+2)/((x-1)*(x^2-3*x+3)*x)]);
    <|unfolded-io>
      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|0>|<cell|1>>|<row|<cell|-<frac|<around*|(|x-2|)>*<around*|(|2*<space|0.17em>x<rsup|2>-3*<space|0.17em>x+3|)>|<around*|(|x-1|)>*<around*|(|x<rsup|2>-3*<space|0.17em>x+3|)>*x>>|<cell|<frac|<around*|(|x<rsup|2>-3|)>*<around*|(|x<rsup|2>-2*<space|0.17em>x+2|)>|<around*|(|x-1|)>*<around*|(|x<rsup|2>-3*<space|0.17em>x+3|)>*x>>>>>>|]>>
    </unfolded-io>

    \;

    \;

    The roots of <math|<around*|(|x<rsup|2>-3*<space|0.17em>x+3|)>*> and
    <math|x> are \ apparent singularities. They are removed in the equivalent
    system. Whereas <math|x=1> is \ not an apparent singularity.\ 

    \;

    \;

    <\unfolded-io>
      <with|color|brown|Maple 12] >
    <|unfolded-io>
      T, invT, B, t := Desing(A, x);
    <|unfolded-io>
      \;

      <math|<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|x<rsup|4>-3*<space|0.17em>x<rsup|3>+3*<space|0.17em>x<rsup|2>>|<cell|1>>|<row|<cell|0>|<cell|1>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|<frac|1|x<rsup|2>*<around*|(|x<rsup|2>-3*<space|0.17em>x+3|)>>>|<cell|-<frac|1|x<rsup|2>*<around*|(|x<rsup|2>-3*<space|0.17em>x+3|)>>>>|<row|<cell|0>|<cell|1>>>>>|]>,<around*|[|<tabular*|<tformat|<cwith|1|-1|1|1|cell-halign|c>|<cwith|1|-1|1|1|cell-lborder|0ln>|<cwith|1|-1|2|2|cell-halign|c>|<cwith|1|-1|2|2|cell-rborder|0ln>|<table|<row|<cell|-2*<space|0.17em><around*|(|x-1|)><rsup|-1>>|<cell|0>>|<row|<cell|-<frac|x*<around*|(|2*<space|0.17em>x<rsup|3>-7*<space|0.17em>x<rsup|2>+9*<space|0.17em>x-6|)>|x-1>>|<cell|1>>>>>|]>,0.642>
    </unfolded-io>

    \;
  </session>

  <section|Other procedures>

  <\itemize-arrow>
    <item>Partial desingularization can be attained via the Maple procedure
    \ <strong|<hlink|DEtools[moser_reduce]|http://www.maplesoft.com/support/help/maple/view.aspx?path=DEtools%2Fsuper_reduce>>.\ 

    <item>The intermediate steps in the algorithm are displayed with the two
    AppSing procedures: \ <strong|DesingpSteps(A,z,p)> and
    <strong|DesingSteps(A,z)>.\ 
  </itemize-arrow>

  <strong|More Examples>:

  Please refer to the Maple sheet on the <hlink|webpage|http://www.unilim.fr/pages_perso/suzy.maddah/Research_.html>.\ 

  \;

  \;

  \;

  This document is written in <hlink|<hlink|TeXmacs|http://www.texmacs.org/tmweb/home/welcome.en.html>.|http://www.texmacs.org/tmweb/home/welcome.en.html>\ 

  <\session|maple|default>
    \ \ \ \ \|\\^/\| \ \ \ \ Maple

    ._\|\\\| \ \ \|/\|_. Copyright (c) Maplesoft, a division of Waterloo
    Maple Inc. 2004

    \ \\OPENMAPLE/ \ All rights reserved. Maple and OpenMaple are trademarks
    of

    \ \<less\>____ ____\<gtr\> \ Waterloo Maple Inc.

    \ \ \ \ \ \ \| \ \ \ \ \ \ Type ? for help.

    \;

    TeXmacs interface by Joris van der Hoeven

    \;

    \;
  </session>
</body>

<\initial>
  <\collection>
    <associate|font-base-size|12>
  </collection>
</initial>

<\references>
  <\collection>
    <associate|DEtools[moser_reduce]http://www.maplesoft.com/support/help/Maple/view.aspx?path=DEtools/super_reduce|<tuple|<with|mode|<quote|math>|<rigid|\<rightarrow\>>>|?>>
    <associate|auto-1|<tuple|1|1>>
    <associate|auto-2|<tuple|2|3>>
    <associate|auto-3|<tuple|3|5>>
    <associate|footnote-1|<tuple|1|1>>
    <associate|footnote-2|<tuple|2|3>>
    <associate|footnote-3|<tuple|3|4>>
    <associate|footnr-1|<tuple|1|1>>
    <associate|footnr-2|<tuple|2|2>>
    <associate|footnr-3|<tuple|3|4>>
  </collection>
</references>

<\auxiliary>
  <\collection>
    <\associate|toc>
      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|1<space|2spc>Desingularization
      at p> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-1><vspace|0.5fn>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|2<space|2spc>Full
      desingularization> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-2><vspace|0.5fn>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|3<space|2spc>Other
      procedures> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-3><vspace|0.5fn>
    </associate>
  </collection>
</auxiliary>